pub enum GuiValidation {
Show 36 variants
UncheckedValue,
DatatypeExpr,
Datacontext,
Datamodel,
Boolean,
Yes,
Align,
Integer,
UnsignedInteger,
Number,
NumberOrInt32,
NumberF,
NumberOrPercent,
TwoNumberOrPercent,
Numeric,
CVector2f,
CVector2i,
CVector3f,
CVector4f,
PointsList,
Color,
CString,
Item(Item),
ItemOrBlank(Item),
Blendmode,
MouseButton(&'static [&'static str]),
MouseButtonSet(&'static [&'static str]),
Choice(&'static [&'static str]),
ChoiceSet(&'static [&'static str]),
Widget,
ActionTooltip,
Format,
FormatOverride,
RawText,
Text,
ComplexProperty,
}Expand description
The various values or blocks or datatype calculations that the gui properties can take.
Variants
UncheckedValue
Accept any value; we don’t know.
DatatypeExpr
A datatype expression; we don’t know the specific type.
Datacontext
A datatype expression that ends with a promote. Can be any type.
Datamodel
A datatype expression that returns a collection of some sort.
Boolean
“yes”, “no”, or a Datatype::bool expression.
Yes
Only a literal “yes” will do.
Align
A |-separated list of values from ALIGN.
Integer
An integer value or a Datatype::int32 expression.
UnsignedInteger
A non-negative integer value or a Datatype::uint32 expression.
Number
A numeric value or a Datatype::float expression.
NumberOrInt32
A numeric value or a Datatype::float or Datatype::int32 expression.
NumberF
A numeric value possibly followed by an f or a Datatype::float expression.
NumberOrPercent
A numeric value, possibly followed by a % mark, or a Datatype::int32 or
Datatype::float expression.
TwoNumberOrPercent
A block with two numeric values, possibly followed by % marks, or a
Datatype::CVector2f expression.
Numeric
A numeric value or a numberlike datatype (one of the floats, ints, or CFixedPoint)
CVector2f
A block with 2 numbers, or a Datatype::CVector2f expression.
CVector2i
A block with 2 integers, or a Datatype::CVector2i expression.
CVector3f
A block with 3 numbers, or a Datatype::CVector3f expression.
CVector4f
A block with 4 numbers, or a Datatype::CVector4f expression.
PointsList
A block with a series of blocks with 2 numbers, or a datatype expression.
Color
A block with 4 numbers (RGBA), or a Datatype::CVector4f expression.
The difference with GuiValidation::CVector4f is in the error messages.
CString
A datatype expression returning a CString
Item(Item)
A key for this item type, or a datatype expression that can be converted to string.
ItemOrBlank(Item)
A key for this item type, or a datatype expression that can be converted to string. May be the empty string.
Blendmode
One of the strings in the BLENDMODES array
MouseButton(&'static [&'static str])
One of the mouse buttons in the array given here.
MouseButtonSet(&'static [&'static str])
A |-separated list of the mouse buttons in the array given here.
Choice(&'static [&'static str])
One of the strings in the array given here.
ChoiceSet(&'static [&'static str])
A |-separated list of strings from the array given here.
Widget
A block containing one widget, or the name of a template containing one widget.
ActionTooltip
An action tooltip block.
Format
A string containing a localization text format specifier starting with #
FormatOverride
A block containing two textformat names
RawText
Some text. May contain datatypes or loca keys, but it’s optional.
Text
Some text. May contain datatypes or loca keys.
ComplexProperty
A property that takes a block of other properties. This block may have override blocks in it.
Implementations
Sourceimpl GuiValidation
impl GuiValidation
Sourcepub fn from_property(property: WidgetProperty) -> Self
pub fn from_property(property: WidgetProperty) -> Self
Get the validation logic for a specific widget property